@@ -107,7 +107,7 @@ def git_clone(prettyname: str, url: str, directory: str,
     Returns:
         did we need to do anything?
     """
-    git = which_and_require(git_executable or "tar")
+    git = which_and_require(git_executable or "git")
     run_func = run_func or subprocess.check_call
     clone_options = clone_options or []  # type: List[str]
     if os.path.isdir(directory):
