@@ -4,7 +4,7 @@
 """
 ===============================================================================
 
-    Original code copyright (C) 2009-2018 Rudolf Cardinal (rudolf@pobox.com).
+    Original code copyright (C) 2009-2019 Rudolf Cardinal (rudolf@pobox.com).
 
     This file is part of cardinal_pythonlib.
 
@@ -39,9 +39,12 @@ from typing import Dict, Union
 
 from prettytable import PrettyTable
 
-from cardinal_pythonlib.logs import main_only_quicksetup_rootlogger
+from cardinal_pythonlib.logs import (
+    BraceStyleAdapter,
+    main_only_quicksetup_rootlogger,
+)
 
-log = logging.getLogger(__name__)
+log = BraceStyleAdapter(logging.getLogger(__name__))
 
 MYSQL_DEFAULT_PORT = 3306
 MYSQL_DEFAULT_USER = 'root'
@@ -73,7 +76,7 @@ def get_mysql_vars(mysql: str,
         "-u", user,
         "-p"  # prompt for password
     ]
-    log.info("Connecting to MySQL with user: {}".format(user))
+    log.info("Connecting to MySQL with user: {}", user)
     log.debug(cmdargs)
     process = subprocess.Popen(cmdargs, stdout=subprocess.PIPE)
     out, err = process.communicate()
